@@ -57,6 +57,7 @@ def main_run(extra_args) -> enum.IntEnum:
 
     extra_args_new.extend(testcase_path_list)
     logger.info(f"start to run tests with pytest. HttpRunner version: {__version__}")
+    parse_diff()
     return pytest.main(extra_args_new)
 
 
@@ -67,13 +68,11 @@ def main():
     parser.add_argument(
         "-V", "--version", dest="version", action="store_true", help="show version"
     )
-
     subparsers = parser.add_subparsers(help="sub-command help")
     sub_parser_run = init_parser_run(subparsers)
     sub_parser_scaffold = init_parser_scaffold(subparsers)
     sub_parser_har2case = init_har2case_parser(subparsers)
     sub_parser_make = init_make_parser(subparsers)
-
     if len(sys.argv) == 1:
         # httprunner
         parser.print_help()
@@ -126,6 +125,16 @@ def main():
         main_make(args.testcase_path)
 
 
+def parse_diff():
+    for i in range(1, len(sys.argv)):
+        if "--diff" in sys.argv[i]:
+            content = str(sys.argv[i].split("=")[1]).split(",")
+            globalvar.set_value('diff', content)
+        if "--env" in sys.argv[i]:
+            content = str(sys.argv[i].split("=")[1]).split(",")
+            globalvar.set_value('env', content)
+
+
 def main_hrun_alias():
     """ command alias
         hrun = httprunner run
