@@ -15,8 +15,10 @@ from requests.exceptions import (
     RequestException,
 )
 
+from rrtv_httprunner import globalvar
 from rrtv_httprunner.models import RequestData, ResponseData
 from rrtv_httprunner.models import SessionData, ReqRespData
+from rrtv_httprunner.response import ResponseObject
 from rrtv_httprunner.utils import lower_dict_keys, omit_long_data, quote_dict, unquote_dict, is_json
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
@@ -248,12 +250,30 @@ class HttpSession(requests.Session):
         Safe mode has been removed from requests 1.x.
         """
         try:
-            a = kwargs["allure"]
+            allure_obj = kwargs["allure"]
+            diff_obj = kwargs["diff"]
+            base_url = kwargs["diff"].base_url
             kwargs.pop("allure")
-            rep = requests.Session.request(self, method, url, **kwargs)
-            a.curl = curlify.to_curl(rep.request, compressed=True)
-            logger.debug(f"curl: {a.curl}")
-            return rep
+            kwargs.pop("diff")
+            globalDiff = globalvar.get_value('diff')
+            if globalDiff is not None and globalDiff != "":
+                if len(globalDiff) >= 2:
+                    master_url = url.replace(base_url, globalDiff[0])
+                    slave_url = url.replace(base_url, globalDiff[1])
+                    master_rep = requests.Session.request(self, method, master_url, **kwargs)
+                    slave_rep = requests.Session.request(self, method, slave_url, **kwargs)
+                    allure_obj.curl = curlify.to_curl(master_rep.request, compressed=True)
+                    logger.debug(f"curl: {allure_obj.curl}")
+                    diff_obj.diff.update({"t1": ResponseObject(master_rep)})
+                    diff_obj.diff.update({"t2": ResponseObject(slave_rep)})
+                    return master_rep
+                else:
+                    raise Exception("diff传入至少两个参数") from None
+            else:
+                rep = requests.Session.request(self, method, url, **kwargs)
+                allure_obj.curl = curlify.to_curl(rep.request, compressed=True)
+                logger.debug(f"curl: {allure_obj.curl}")
+                return rep
         except (MissingSchema, InvalidSchema, InvalidURL):
             raise
         except RequestException as ex:
