@@ -10,7 +10,7 @@ from sentry_sdk import capture_exception
 from rrtv_httprunner import loader, utils, exceptions
 from rrtv_httprunner.models import VariablesMapping, FunctionsMapping, data_enum
 from rrtv_httprunner.utils import execute_sql, execute_cmd, get_statement_type, execute_redis, execute_mongo, \
-    remove_bracket_first, legitimate_method_call
+    remove_bracket_first, legitimate_method_call, execute_es
 
 absolute_http_url_regexp = re.compile(r"^https?://", re.I)
 
@@ -487,6 +487,15 @@ def parse_data(
                     return execute_mongo(variables_mapping[data_enum.MONGO], var_value)
             except KeyError:  # 没配置数据源
                 raise exceptions.DBError("mongo datasource not configured")
+        elif get_statement_type(var_value) == data_enum.ES:
+            try:
+                if data_enum.DB_CONFIG_SYMBOL in var_value:  # 指定环境执行es
+                    return execute_es(var_value.split(data_enum.DB_CONFIG_SYMBOL)[1],
+                                      var_value.split(data_enum.DB_CONFIG_SYMBOL)[0])
+                else:
+                    return execute_es(variables_mapping[data_enum.ES], var_value)
+            except KeyError:  # 没配置数据源
+                raise exceptions.DBError("elasticsearch datasource not configured")
         else:
 
             if isinstance(var_value, dict):
@@ -570,6 +579,8 @@ def parse_variables_mapping(
                 parsed_value = parse_data(
                     var_value, variables_mapping, functions_mapping
                 )
+                extract_mapping = {var_name: parsed_value}
+                variables_mapping.update(extract_mapping)
                 # parsed_value = parse_data(
                 #     var_value, parsed_variables, functions_mapping
                 # )
