@@ -16,7 +16,7 @@ except ModuleNotFoundError:
 # import allure
 from loguru import logger
 
-from rrtv_httprunner import utils, exceptions
+from rrtv_httprunner import utils, exceptions, globalvar
 from rrtv_httprunner.client import HttpSession
 from rrtv_httprunner.exceptions import ValidationFailure, ParamsError
 from rrtv_httprunner.ext.uploader import prepare_upload_step
@@ -31,12 +31,12 @@ from rrtv_httprunner.models import (
     TestCaseInOut,
     ProjectMeta,
     TestCase,
-    Hooks, data_enum, AllureParameter,
+    Hooks, data_enum, AllureParameter, DiffParameter
 )
 from rrtv_httprunner.parser import build_url, parse_data, parse_variables_mapping
 from rrtv_httprunner.response import ResponseObject
 from rrtv_httprunner.testcase import Config, Step
-from rrtv_httprunner.utils import merge_variables
+from rrtv_httprunner.utils import merge_variables, write_excel
 
 
 class HttpRunner(object):
@@ -219,7 +219,10 @@ class HttpRunner(object):
         parsed_request_dict["json"] = parsed_request_dict.pop("req_json", {})
 
         a = AllureParameter()
+        diff_obj = DiffParameter()
+        diff_obj.base_url = self.__config.base_url
         parsed_request_dict["allure"] = a
+        parsed_request_dict["diff"] = diff_obj
         # request
         resp = self.__session.request(method, url, **parsed_request_dict)
         resp_obj = ResponseObject(resp)
@@ -274,6 +277,11 @@ class HttpRunner(object):
 
         # validate
         validators = step.validators
+        if diff_obj.diff != {}:
+            validators = []
+            validators.append(
+                {'t1': resp_obj.body, 't2': demjson.decode(diff_obj.diff["t2"].resp_obj.text), 'kwargs': {},
+                 'message': ''})
         session_success = False
         try:
             resp_obj.validate(
@@ -299,13 +307,23 @@ class HttpRunner(object):
                 # save step data
                 step_data.data = self.__session.data
 
-        # teardown hooks
-        if step.teardown_hooks:
-            self.__call_hooks(step.teardown_hooks, step.variables, "teardown request")
+                # teardown hooks
+                if step.teardown_hooks:
+                    self.__call_hooks(step.teardown_hooks, step.variables, "teardown request")
+
+                # 执行teardown
+                if step.teardown:
+                    self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
+            if globalvar.get_value("toexcel", "") != "":
+                location = ""
+                for marks in self.pytestmark:
+                    if "location" == marks.name:
+                        location = marks.args[0]
+                content = {"dir": self.config.path, "base_url": self.__config.base_url, "url": url_path,
+                           "method": method, "name": self.config.name,
+                           "location": location, "curl": a.curl}
+                write_excel(content, globalvar.get_value("toexcel"))
 
-        # 执行teardown
-        if step.teardown:
-            self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
         return step_data
 
     def __run_step_testcase(self, step: TStep) -> StepData:
@@ -483,7 +501,7 @@ class HttpRunner(object):
     def get_summary(self) -> TestCaseSummary:
         """get testcase result summary"""
         start_at_timestamp = self.__start_at
-        start_at_iso_format = datetime.utcfromtimestamp(start_at_timestamp).isoformat()
+        start_at_iso_format = datetime.datetime.fromtimestamp(start_at_timestamp).isoformat()
         return TestCaseSummary(
             name=self.__config.name,
             success=self.success,
