@@ -10,11 +10,13 @@ from multiprocessing import Queue
 from typing import Dict, List, Any, Text, NoReturn, Union
 from urllib.parse import quote, unquote
 
+import pandas as pd
 import sentry_sdk
 from loguru import logger
 
 from rrtv_httprunner import __version__
 from rrtv_httprunner import exceptions
+from rrtv_httprunner.es import ESHandler
 from rrtv_httprunner.models import VariablesMapping
 from rrtv_httprunner.mongo import MongoHandler
 from rrtv_httprunner.mysqls import MySQLHandler
@@ -204,13 +206,14 @@ def merge_variables(
     """ merge two variables mapping, the first variables have higher priority
     """
     step_new_variables = {}
-    for key, value in variables.items():
-        if f"${key}" == value or "${" + key + "}" == value:
-            # e.g. {"base_url": "$base_url"}
-            # or {"base_url": "${base_url}"}
-            continue
-
-        step_new_variables[key] = value
+    if variables.items() is not None:
+        for key, value in variables.items():
+            if key is not None:
+                if f"${str(key)}" == value or "${" + str(key) + "}" == value:
+                    # e.g. {"base_url": "$base_url"}
+                    # or {"base_url": "${base_url}"}
+                    continue
+                step_new_variables[key] = value
 
     merged_variables = copy.copy(variables_to_be_overridden)
     merged_variables.update(step_new_variables)
@@ -291,6 +294,8 @@ def get_statement_type(statement: Text) -> Text:
             return "redis"
         elif statement.lower().startswith("mongo:"):
             return "mongo"
+        elif statement.lower().startswith("es:"):
+            return "es"
         elif statement.lower().startswith("cmd:"):
             return "cmd"
 
@@ -332,26 +337,29 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
 
     def execute(config, content):
         handler = RedisHandler(config)
-        if parsed_string.lower().startswith("get("):
-            return handler.str_get(content[0])
-        elif parsed_string.lower().startswith("hget("):
-            handler.hash_hkeys(content[0]) if len(content) == 1 else handler.hash_get(content[0], content[1])
-        elif parsed_string.lower().startswith("hkeys("):
-            handler.hash_hkeys(content[0])
-        elif parsed_string.lower().startswith("set("):
-            return handler.str_set(content[0], content[1])
-        elif parsed_string.lower().startswith("hset("):
-            return handler.hash_set(content[0], content[1], content[2])
-        elif parsed_string.lower().startswith("del("):
-            return handler.delete(content[0])
-        elif parsed_string.lower().startswith("hdel("):
-            return handler.str_set(content[0], content[1])
-        elif parsed_string.lower().startswith("clean") and parsed_string != "clean_redis":
-            return handler.clean_redis
-        else:
-            scope = {'handler': RedisHandler(config)}
-            cli = "handler." + parsed_string
-            return eval(cli, scope)
+        try:
+            if parsed_string.lower().startswith("get("):
+                return handler.str_get(content[0])
+            elif parsed_string.lower().startswith("hget("):
+                handler.hash_hkeys(content[0]) if len(content) == 1 else handler.hash_get(content[0], content[1])
+            elif parsed_string.lower().startswith("hkeys("):
+                handler.hash_hkeys(content[0])
+            elif parsed_string.lower().startswith("set("):
+                return handler.str_set(content[0], content[1])
+            elif parsed_string.lower().startswith("hset("):
+                return handler.hash_set(content[0], content[1], content[2])
+            elif parsed_string.lower().startswith("del("):
+                return handler.delete(content[0])
+            elif parsed_string.lower().startswith("hdel("):
+                return handler.hash_del(content[0], content[1])
+            elif parsed_string.lower().startswith("clean") and parsed_string != "clean_redis":
+                return handler.clean_redis
+            else:
+                scope = {'handler': RedisHandler(config)}
+                cli = "handler." + parsed_string
+                return eval(cli, scope)
+        except:
+            raise Exception("检测传入key是否错误")
 
     match_start_position = cli.index(":", 0)
     parsed_string = cli[match_start_position + 1:]
@@ -386,7 +394,7 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
         return execute(data_source, content)
 
 
-def execute_mongo(db: Union[str, dict], operation: Text) -> Text:
+def execute_mongo(db: Union[Text, Dict], operation: Text) -> Text:
     match_start_position = operation.index(":", 0)
     parsed_string = operation[match_start_position + 1:]
     logger.debug("execute mongodb: { " + parsed_string + " }")
@@ -395,6 +403,17 @@ def execute_mongo(db: Union[str, dict], operation: Text) -> Text:
     return eval(cli, scope)
 
 
+def execute_es(data_source: Union[Text, Dict], operation: Text) -> Text:
+    match_start_position = operation.index(":", 0)
+    parsed_string = operation[match_start_position + 1:]
+    logger.debug("execute elasticsearch: { " + parsed_string + " }")
+    if isinstance(data_source, Text):
+        data_source = eval(data_source)
+    scope = {'handler': ESHandler(data_source["hosts"], index=data_source["index"])}
+    cli = "handler." + parsed_string
+    return eval(cli, scope)
+
+
 def remove_bracket(word):
     if "[" not in word and "]" not in word:
         return word
@@ -452,3 +471,57 @@ def legitimate_method_call(value):
         return True
     else:
         return True
+
+
+def write_excel(content: Dict, target_dir):
+    file = target_dir
+    APP = "env-gateway"
+    FRIDAY = "inner-gateway"
+    OPEN = "open-gateway"
+    WEB = "web-gateway"
+    try:
+        app = pd.read_excel(file, sheet_name=APP)
+        friday = pd.read_excel(file, sheet_name=FRIDAY)
+        open = pd.read_excel(file, sheet_name=OPEN)
+        ugc = pd.read_excel(file, sheet_name=WEB)
+    except:
+        df = pd.DataFrame({"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "curl": []})  # 结构
+        writer = pd.ExcelWriter(file, engine="openpyxl")
+        df.to_excel(writer, sheet_name=APP, index=False)
+        df.to_excel(writer, sheet_name=FRIDAY, index=False)
+        df.to_excel(writer, sheet_name=OPEN, index=False)
+        df.to_excel(writer, sheet_name=WEB, index=False)
+        writer.save()
+        writer.close()
+        app = pd.read_excel(file, sheet_name=APP)
+        friday = pd.read_excel(file, sheet_name=FRIDAY)
+        open = pd.read_excel(file, sheet_name=OPEN)
+        ugc = pd.read_excel(file, sheet_name=WEB)
+
+    tier = get_testcases_tier(content["dir"])
+    service = tier[2] if tier[0] == "gateway_api" else ""
+    add_data = [service.replace("_", "-"), content["method"], content["url"], content["name"], content["location"],
+                content["curl"]]
+
+    with pd.ExcelWriter(file, mode='a', engine='openpyxl', if_sheet_exists='replace') as writer:
+        if "gateway" in tier[0]:
+            if "app_gateway" in tier:
+                app.loc[-1] = add_data
+                app.to_excel(writer, sheet_name=APP, index=False)
+            elif "inner_gateway" in tier:
+                friday.loc[-1] = add_data
+                friday.to_excel(writer, sheet_name=FRIDAY, index=False)
+            elif "open_gateway" in tier:
+                open.loc[-1] = add_data
+                open.to_excel(writer, sheet_name=OPEN, index=False)
+            elif "web_gateway" in tier:
+                ugc.loc[-1] = add_data
+                ugc.to_excel(writer, sheet_name=WEB, index=False)
+
+
+def get_testcases_tier(dir):
+    """
+    获取用例层级
+    """
+    testcases_after = dir.split("testcases/")[1]
+    return testcases_after.split("/")
